==> KidozSDK-0.7.1-sources.jar: com/kidoz/sdk/api/ui_views/html_view/HtmlJavaScriptInterafce.java <==
package com.kidoz.sdk.api.ui_views.html_view;

/**
 * Created by Eugine on 11/17/2016.
 */

public interface HtmlJavaScriptInterafce
{
    @android.webkit.JavascriptInterface
    void onViewReady();

    @android.webkit.JavascriptInterface
    void simulateClick(String contentItemJson, int positionIndex);

    @android.webkit.JavascriptInterface
    void onSendImpressionEvent(String item_id, String item_name, String ad_id, String view_index);

    @android.webkit.JavascriptInterface
    void onInvokeAboutClick();

    @android.webkit.JavascriptInterface
    void onInvokeParentalClick();

    @android.webkit.JavascriptInterface
    void onInvokeCloseClick();

    @android.webkit.JavascriptInterface
    void onInvokeMaximize();

    @android.webkit.JavascriptInterface
    void onInitWebViewWithProperties(String properties);

    @android.webkit.JavascriptInterface
    void onSendConversionEvent(String item_id, String item_name, String ad_id, String view_index, String rewardKey, String rewardValue);

    @android.webkit.JavascriptInterface
    void onStoreLocalParameter(String key, String value, String scope_type);

    @android.webkit.JavascriptInterface
    void getLocalParameter(final String function, final String key);

    @android.webkit.JavascriptInterface
    void onDone();

    @android.webkit.JavascriptInterface
    void getParentalLockStatus(String function);

    @android.webkit.JavascriptInterface
    void forwardToGooglePlay(final String advertiserID, final String appID, final String googlePlayLink, final String widjetType, final String styleID, final String itemIndex);

    @android.webkit.JavascriptInterface
    void sendEvent(String type, String category, String action, String label, String jsonData);

    @android.webkit.JavascriptInterface
    void toggleLoadingState(String isLoading);

    @android.webkit.JavascriptInterface
    void notifyIsVastAdReady(boolean isVastReady, String vastSettings);

    @android.webkit.JavascriptInterface
    void notifyIsVastAdReady(boolean isVastReady);

    @android.webkit.JavascriptInterface
    void onRewarded();

    @android.webkit.JavascriptInterface
    void onRewardedVideoStarted();

    @android.webkit.JavascriptInterface
    void onAdStateChanged(int state);

    @android.webkit.JavascriptInterface
    void toggleWidgetState(boolean isEnables);

    @android.webkit.JavascriptInterface
    void setDeviceOrientation(int orientation);
}

==> KidozSDK-0.7.4-sources.jar: com/kidoz/sdk/api/ui_views/html_view/HtmlJavaScriptInterafce.java <==
package com.kidoz.sdk.api.ui_views.html_view;

/**
 * Created by Eugine on 11/17/2016.
 */

public interface HtmlJavaScriptInterafce
{
    @android.webkit.JavascriptInterface
    void onViewReady();

    @android.webkit.JavascriptInterface
    void simulateClick(String contentItemJson, int positionIndex);

    @android.webkit.JavascriptInterface
    void onSendImpressionEvent(String item_id, String item_name, String ad_id, String view_index);

    @android.webkit.JavascriptInterface
    void onInvokeAboutClick();

    @android.webkit.JavascriptInterface
    void onInvokeParentalClick();

    @android.webkit.JavascriptInterface
    void onInvokeCloseClick();

    @android.webkit.JavascriptInterface
    void onInvokeMaximize();

    @android.webkit.JavascriptInterface
    void onInitWebViewWithProperties(String properties);

    @android.webkit.JavascriptInterface
    void onSendConversionEvent(String item_id, String item_name, String ad_id, String view_index, String rewardKey, String rewardValue);

    @android.webkit.JavascriptInterface
    void onStoreLocalParameter(String key, String value, String scope_type);

    @android.webkit.JavascriptInterface
    void getLocalParameter(final String function, final String key);

    @android.webkit.JavascriptInterface
    void onDone();

    @android.webkit.JavascriptInterface
    void getParentalLockStatus(String function);

    @android.webkit.JavascriptInterface
    void forwardToGooglePlay(final String advertiserID, final String appID, final String googlePlayLink, final String widjetType, final String styleID, final String itemIndex);

    @android.webkit.JavascriptInterface
    void sendEvent(String type, String category, String action, String label, String jsonData);

    @android.webkit.JavascriptInterface
    void toggleLoadingState(String isLoading);

    @android.webkit.JavascriptInterface
    void notifyIsVastAdReady(boolean isVastReady, String vastSettings);

    @android.webkit.JavascriptInterface
    void notifyIsAdReady(boolean isAdReady, String adSettings);

    @android.webkit.JavascriptInterface
    void notifyIsVastAdReady(boolean isVastReady);

    @android.webkit.JavascriptInterface
    void onRewarded();

    @android.webkit.JavascriptInterface
    void onRewardedVideoStarted();

    @android.webkit.JavascriptInterface
    void onAdStateChanged(int state);

    @android.webkit.JavascriptInterface
    void toggleWidgetState(boolean isEnables);

    @android.webkit.JavascriptInterface
    void setDeviceOrientation(int orientation);

    @android.webkit.JavascriptInterface
    void sendURLEvent(String eventUrl);

    @android.webkit.JavascriptInterface
    void playVideo(String url);
}
